
# Type: slot_definitions


slot definitions

URI: [meta:slot_definitions](https://w3id.org/biolink/biolinkml/meta/slot_definitions)


## Domain and Range

[SchemaDefinition](SchemaDefinition.md) ->  <sub>0..*</sub> [SlotDefinition](SlotDefinition.md)

## Parents


## Children


## Used by

 * [SchemaDefinition](SchemaDefinition.md)
